@@ -289,6 +289,10 @@ class TransactionInvoice(TransactionAwareEntity):
         :param external_id: The external_id of this TransactionInvoice.
         :type: str
         """
+        if external_id is not None and len(external_id) > 100:
+            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
+        if external_id is not None and len(external_id) < 1:
+            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")
 
         self._external_id = external_id
     
@@ -358,6 +362,8 @@ class TransactionInvoice(TransactionAwareEntity):
         :param merchant_reference: The merchant_reference of this TransactionInvoice.
         :type: str
         """
+        if merchant_reference is not None and len(merchant_reference) > 100:
+            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")
 
         self._merchant_reference = merchant_reference
     
